==> gbsite-1.0.0.tar.gz: gbsite/templates/gb/gb_pgfeaturespage.php <==
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td width="20"><img src="<?= $image_path ?>/shim.gif" width=20 height=1 alt="" border="0"></td>
<td width="100%">              
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>">
PostgreSQL offers the features and functions required for developing and deploying full-service e-business solutions.
<p>
<b>Indexes</b><br>
PostgreSQL supports multiple index types: B-Tree, R-Tree, and Hash.  The index type is user-specified allowing the user to select the most efficient index for each application.  Unique indices may be declared to prevent multiple records from having the same key, ensuring data consistency and eliminating the chance of having duplicate records.  PostgreSQL also supports concatenated (or compound) keys, functionality that is particularly useful in data mining.  And each table in a PostgreSQL database can support a clustered index, allowing for the fastest possible data retrieval time.
<p>
<b>Data Types</b><br>
PostgreSQL supports many more datatypes than are required by the 1992 ANSI SQL Standard.  These include Character, Numeric, Date/Time, Logical, Geometric, and Network data types.<p>
<p>           
<b>Data Integrity</b><br>
PostgreSQL offers a multitude of functions and features for data protection and security, including:
<ul>
<li><i>Multi-version concurrency control:</i> to reduce the contention between users for the same data - better than most commercial row-level locking schemes.
<li><i>Commit/Rollback:</i> allows transactions to be isolated so they can be rolled back in the event of a failure of any other corresponding, isolated transaction.
<li><i>Checkpoints:</i> a "checkpoint" forces all completed transactions to be written from RAM to disk, a persistent, safe storage device to ensure the integrity of data.
<li><i>Triggers:</i> user-written procedures which can be configured to fire off in the event of a transaction against a table, ensuring referential integrity (consistency) between tables in a database.
<li><i>Constraints:</i> supports Declarative Referential Integrity (DRI) as enforced by constraints placed on a table when it is created, to ensure that every child record has a parent record in another table.
<li><i>On-line Backup:</i> allows for on-line, or "hot" backups to be run without users having to log out of the database, to archive a database without any disruption to those using the database.<p>
</ul>            
<p>
<b>Functions</b><br>        
PostgreSQL has placed often-used snippets of code into "functions" which can be called by the programmers.  In addition to the most common functions (such as Count, Sum, Max, Min and Average), PostgreSQL also supports numerous other functions including Mathematical, String Manipulation, Data/Time Conversion, Formatting, and Geometric functions.  Even more flexibility is provided through PostgreSQL's support of User-Defined Functions, which allow a developer to encapsulate the code required to perform user-specified tasks.
<p> 
<b>Coming Soon</b><br>
The following features are currently in development for PostgreSQL and will be available later this year: write-ahead logging (or "redo" logging), outer joins, and longer data row support.  These features will keep PostgreSQL ahead of the open source database pack, and strengthen its capabilities for mission critical deployment.<p> 
<p>
<b>Platform</b><br>
PostgreSQL supports numerous operating systems, both open and proprietary.  These platforms include: Linux, xBSD, Solaris, HP-UX, AIX, Irix, Nextstep, Windows NT/2000 and more.<p>
<p>
<b>Programming Languages</b><br>
PostgreSQL supports many Programming Languages, including: C, C++, Embedded C, Java, PHP, Perl, Python, Tcl, and more.  Other languages and development environments may access the database through its support of the Open Database Connectivity (ODBC) and Java Database Connectivity (JDBC) specifications.<p>
</font><p><br>
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>"><a href="/postgresql/resources.php">continue to Resources</a></font>  
</td>          
</tr>              
</table>

==> gbsite-2.0.0.tar.gz: gbsite/templates/gb/gb_pgfeaturespage.php <==
<table cellpadding="0" cellspacing="0" border="0" width="100%">
<tr>
<td width="20"><img src="<?= $image_path ?>/shim.gif" width=20 height=1 alt="" border="0"></td>
<td width="100%">              
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>">
PostgreSQL offers the features and functions required for developing and deploying full-service e-business solutions.
<p>
<b>Indexes</b><br>
PostgreSQL supports multiple index types: B-Tree, R-Tree, and Hash.  The index type is user-specified allowing the user to select the most efficient index for each application.  Unique indices may be declared to prevent multiple records from having the same key, ensuring data consistency and eliminating the chance of having duplicate records.  PostgreSQL also supports concatenated (or compound) keys, functionality that is particularly useful in data mining.  And each table in a PostgreSQL database can support a clustered index, allowing for the fastest possible data retrieval time.
<p>
<b>Data Types</b><br>
PostgreSQL supports many more datatypes than are required by the 1992 ANSI SQL Standard.  These include Character, Numeric, Date/Time, Logical, Geometric, and Network data types.<p>
<p>           
<b>Data Integrity</b><br>
PostgreSQL offers a multitude of functions and features for data protection and security, including:
<ul>
<li><i>Multi-version concurrency control:</i> to reduce the contention between users for the same data - better than most commercial row-level locking schemes.
<li><i>Commit/Rollback:</i> allows transactions to be isolated so they can be rolled back in the event of a failure of any other corresponding, isolated transaction.
<li><i>Checkpoints:</i> a "checkpoint" forces all completed transactions to be written from RAM to disk, a persistent, safe storage device to ensure the integrity of data.
<li><i>Triggers:</i> user-written procedures which can be configured to fire off in the event of a transaction against a table, ensuring referential integrity (consistency) between tables in a database.
<li><i>Constraints:</i> supports Declarative Referential Integrity (DRI) as enforced by constraints placed on a table when it is created, to ensure that every child record has a parent record in another table.
<li><i>On-line Backup:</i> allows for on-line, or "hot" backups to be run without users having to log out of the database, to archive a database without any disruption to those using the database.<p>
</ul>            
<p>
<b>Functions</b><br>        
PostgreSQL has placed often-used snippets of code into "functions" which can be called by the programmers.  In addition to the most common functions (such as Count, Sum, Max, Min and Average), PostgreSQL also supports numerous other functions including Mathematical, String Manipulation, Data/Time Conversion, Formatting, and Geometric functions.  Even more flexibility is provided through PostgreSQL's support of User-Defined Functions, which allow a developer to encapsulate the code required to perform user-specified tasks.
<p> 
<b>Coming Soon</b><br>
The following features are currently in development for PostgreSQL and will be available in early 2001: write-ahead logging (or "redo" logging), outer joins, and longer data row support.  These features will keep PostgreSQL ahead of the open source database pack, and strengthen its capabilities for mission critical deployment.<p> 
<p>
<b>Platform</b><br>
PostgreSQL supports numerous operating systems, both open and proprietary.  These platforms include: Linux, xBSD, Solaris, HP-UX, AIX, Irix, Nextstep, Windows NT/2000 and more.<p>
<p>
<b>Programming Languages</b><br>
PostgreSQL supports many Programming Languages, including: C, C++, Embedded C, Java, PHP, Perl, Python, Tcl, and more.  Other languages and development environments may access the database through its support of the Open Database Connectivity (ODBC) and Java Database Connectivity (JDBC) specifications.<p>
</font><p><br>
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1 ?>"><a href="/postgresql/resources.php">continue to Resources</a></font>  
</td>          
</tr>              
</table>
